searchNodes=[{"doc":"Standardized event handling in LiveViews and LiveComponents. The problem LiveView currently has two built-in mechanisms for sending messages between views and components: send/2 -&gt; handle_info/2 for sending to a LiveView send_update/3 -&gt; update/2 for sending to a LiveComponent Picking a singular approach limits component reusability, and using both approaches results in an inconsistent event API. The solution LiveEvent standardizes these systems into a singular flow: emit/3 -&gt; LiveEvent.handle_event/4 for sending to a LiveView or LiveComponent When use LiveEvent.LiveComponent or use LiveEvent.LiveView is invoked, it hooks into the lifecycle of the view or component to transparently add support for the LiveEvent.handle_event/4 callback. Event destinations Imagine a LiveComponent that has an :on_selected event assign that is raised like so: emit ( socket , :on_selected ) To handle the event on a LiveView, pass a pid to the event assign. &lt; .live_component module = { MyComponent } id = &quot;foo&quot; on_selected = { self ( ) } &gt; To handle the event on a LiveComponent, pass {module, id} to the event assign. &lt; .live_component module = { MyComponent } id = &quot;foo&quot; on_selected = { { __MODULE__ , @id } } &gt; In both cases, the event is handled by the LiveEvent.handle_event/4 callback. # On a LiveView OR LiveComponent def handle_event ( :on_selected , { MyComponent , &quot;foo&quot; } , _payload , socket ) , do : ... Example defmodule MyLiveView do use Phoenix.LiveView use LiveEvent.LiveView def render ( assigns ) do ~H&quot;&quot;&quot; &lt;.live_component module={MyLiveComponent} id=&quot;my-component&quot; on_selected={self()} /&gt; &quot;&quot;&quot; end def handle_event ( :on_selected , { MyLiveComponent , &quot;my-component&quot; } , %{ at : at } , socket ) do IO . puts ( &quot;Selected at \#{ at } &quot; ) { :ok , socket } end end defmodule MyLiveComponent do use Phoenix.LiveComponent use LiveEvent.LiveComponent def render ( assigns ) do ~H&quot;&quot;&quot; &lt;button phx-click=&quot;click&quot; phx-targt={@myself}&gt;Click me&lt;/button&gt; &quot;&quot;&quot; end def handle_event ( &quot;click&quot; , _ , socket ) do { :noreply , emit ( socket , :on_selected , %{ at : DateTime . utc_now ( ) } ) } end end","ref":"LiveEvent.html","title":"LiveEvent","type":"behaviour"},{"doc":"Raise an event from a LiveView or LiveComponent. The event_name argument is the name of the optional socket assign whose value specifies the destination for the event. The name of the emitted event defaults to the name of the assign. Possible assign values are: nil to not raise the event a pid, to send the event to a LiveView {pid, event_name} to send the event to a LiveView with a custom event name {module, id} to send the event to a LiveComponent {module, id, event_name} to send the event to a LiveComponent with a custom event name Returns the unmodified socket.","ref":"LiveEvent.html#emit/3","title":"LiveEvent.emit/3","type":"function"},{"doc":"Handle an event message sent by emit/3 or send_event/4 . Events sent via emit/3 have a source argument of the form {module, id} . Compared to handle_event/3 This callback is distinct from LiveView's handle_event/3 callback in a few important ways: The arity is different The result is {:ok, socket} , not {:noreply, socket} LiveEvent uses atoms for event names, not strings LiveEvent always originate from the server, not the client Example def handle_event ( :on_profile_selected , { MyLiveComponent , _id } , profile_id , socket ) , do : ...","ref":"LiveEvent.html#c:handle_event/4","title":"LiveEvent.handle_event/4","type":"callback"},{"doc":"Send an event to a LiveView or LiveComponent. Typically, emit/3 should be used to send events, but this function can be used if more control is needed. To send to a LiveView (or any other process), specify a pid (usually self() ) as the destination . To send to a LiveComponent, specify {module, id} as the destination . The event can handled by the LiveEvent.handle_event/4 callback. When sending to an arbitrary process, the message will be a LiveEvent.Event struct, although you should not normally have to deal with that directly. Options :source - where the event originated from; defaults to nil Examples send_event ( self ( ) , :on_selected , %{ profile_id : 123 } ) # =&gt; def handle_event(:on_selected, _source, %{profile_id: id}, socket), do: ... send_event ( { MyComponent , &quot;my-id&quot; } , :on_selected , %{ profile_id : 123 } ) # =&gt; def handle_event(:on_selected, _source, %{profile_id: id}, socket), do: ...","ref":"LiveEvent.html#send_event/4","title":"LiveEvent.send_event/4","type":"function"},{"doc":"Represents an event message. This is documented in the unlikely chance that the destination process or component needs to directly handle it. This struct should not be constructed directly by the developer - use LiveEvent.send_event/4 and LiveEvent.emit/3 instead.","ref":"LiveEvent.Event.html","title":"LiveEvent.Event","type":"module"},{"doc":"","ref":"LiveEvent.Event.html#t:destination/0","title":"LiveEvent.Event.destination/0","type":"type"},{"doc":"","ref":"LiveEvent.Event.html#t:t/0","title":"LiveEvent.Event.t/0","type":"type"},{"doc":"Add LiveEvent support to LiveComponents. Simply add use LiveEvent.LiveComponent to your LiveComponent module. See LiveEvent for more information on how to emit and handle events. The macro imports LiveEvent.emit/3 and hooks into the LiveComponent update lifecycle to add support for the LiveEvent.handle_event/4 callback.","ref":"LiveEvent.LiveComponent.html","title":"LiveEvent.LiveComponent","type":"module"},{"doc":"Add LiveEvent support to LiveViews. Simply add use LiveEvent.LiveView to your LiveView module. See LiveEvent for more information on how to emit and handle events. The macro imports LiveEvent.emit/3 and hooks into the LiveView lifecycle to add support for the LiveEvent.handle_event/4 callback.","ref":"LiveEvent.LiveView.html","title":"LiveEvent.LiveView","type":"module"}]